netapp_ontap.models.ems_destination_response_records API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ems_destination_response_records`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class EmsDestinationResponseRecordsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the EmsDestinationResponseRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `access_control_role: Role GET`

    The access_control_role field of the ems_destination_response_records.

  `certificate: EmsCertificate GET POST PATCH`

    Specifies the client-side certificate used by the ONTAP system when mutual authentication is required. This object is only applicable for rest_api type destinations. Both the `ca` and `serial_number` fields must be specified when configuring a certificate in a PATCH or POST request. The `name` field is read-only and cannot be used to configure a client-side certificate.

  `connectivity: EmsDestinationResponseRecordsConnectivity GET POST PATCH`

    The connectivity field of the ems_destination_response_records.

  `destination: str GET POST PATCH`

    Event destination

    Example: administrator@mycompany.com

  `filters: List[EmsDestinationFilters] GET POST PATCH`

    The filters field of the ems_destination_response_records.

  `links: SelfLink GET`

    The links field of the ems_destination_response_records.

  `name: str GET POST`

    Destination name. Valid in POST.

    Example: Admin_Email

  `syslog: EmsSyslog GET POST PATCH`

    The syslog field of the ems_destination_response_records.

  `system_defined: bool GET`

    Flag indicating system-defined destinations.

    Example: true

  `type: str GET POST`

    Type of destination. Valid in POST.

    Valid choices:

    - snmp
    - email
    - syslog
    - rest_api